GlobalContext

Struct GlobalContext 

pub struct GlobalContext { /* private fields */ }
Global context manager for shared state

This provides a global context that can be shared across threads in environments that support it (not available in WASM).

Implementations

Source

impl GlobalContext

pub fn new() -> Self

Create a new global context

pub fn set<T: 'static + Send + Sync>(&self, value: T)

Set a typed value in the global context

pub fn get<T: 'static + Send + Sync + Clone>(&self) -> Option<T>

Get a typed value from the global context

pub fn remove<T: 'static + Send + Sync>(&self) -> bool

Remove a typed value from the global context

pub fn clear(&self)

Clear all global context values