ThreadLocalContext

Struct ThreadLocalContext 

pub struct ThreadLocalContext;
Thread-local context storage

This provides WASM-compatible thread-local context storage that automatically cleans up when contexts go out of scope.

Implementations

Source

impl ThreadLocalContext

pub fn new() -> Self

Create a new thread-local context

pub fn set<T: 'static>(&self, value: T)

Set a typed value in the context

pub fn get<T: 'static + Clone>(&self) -> Option<T>

Get a typed value from the context

pub fn remove<T: 'static>(&self) -> Option<T>

Remove a typed value from the context

pub fn clear(&self)

Clear all context values

pub fn scoped<T: 'static + Clone>( &self, value: T, ) -> Guard<T, impl FnOnce(T) + use<T>>

Create a scoped context guard for a typed value