pub struct NoOpGuard;Expand description
No-op guard that does nothing
This is useful as a placeholder when guards are conditionally created but you still want to maintain the same interface.
Implementations