pub struct GlobalContext { /* private fields */ }Expand description
Global context manager for shared state
This provides a global context that can be shared across threads in environments that support it (not available in WASM).
Implementations