pub struct ContextGuard<T, S, C>{ /* private fields */ }Expand description
Context guard that manages thread-local or scoped context
This is a specialized guard for managing context that needs to be set and cleared in a scoped manner.
Implementations
Sourceimpl<T, S, C> ContextGuard<T, S, C>
impl<T, S, C> ContextGuard<T, S, C>
Sourcepub fn new(context: T, setter: S, clearer: C) -> Self
pub fn new(context: T, setter: S, clearer: C) -> Self
Create a new context guard
Arguments
context: The context value to managesetter: Function to set the contextclearer: Function to clear the context
Example
use foundation_utils::raii::ContextGuard;
let _guard = ContextGuard::new(
"my_context",
|ctx| println!("set: {}", ctx),
|| println!("cleared"),
);
// Context is automatically cleared when guard dropsTrait Implementations